@@ -113,7 +113,7 @@ static void showHelp()
    #endif
 }
 
-QString getTranslationDir()
+QString getTranslationDir(const QString& locale)
 {
    #ifdef _WIN32
       wchar_t buf[200];
@@ -125,7 +125,7 @@ QString getTranslationDir()
       else       {  exePath = "."; }
       return exePath+"/translations";
    #else
-      return ".";
+      return  (QString)"/usr/share/locale/" + locale + "/LC_MESSAGES";
    #endif
 }
 
@@ -682,7 +682,7 @@ KToggleAction* KStandardAction::showToolbar( QWidget* parent, const char* slot,
 KToggleAction* KStandardAction::showStatusbar( QWidget* parent, const char* slot, KActionCollection* actionCollection)
 {
    KMainWindow* p = actionCollection->m_pMainWindow;
-   KToggleAction* a = new KToggleAction( i18n("Show &Statusbar"), 0, parent, slot, actionCollection, "showstatusbar", false );
+   KToggleAction* a = new KToggleAction( i18n("Show &Status Bar"), 0, parent, slot, actionCollection, "showstatusbar", false );
    if(p) p->settingsMenu->addAction( a );
    return a;
 }
