@@ -42,7 +42,7 @@ class QLabel;
 #include <map>
 #include <list>
 
-QString getTranslationDir();
+QString getTranslationDir(const QString&);
 
 class KMainWindow;
 class KAction;
