@@ -24,15 +24,15 @@
 #include <algorithm>
 #include <ctype.h>
 
-#include <qclipboard.h>
+#include <QClipboard>
 #include <qscrollbar.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
-#include <qsplitter.h>
-#include <qdir.h>
-#include <qfile.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
+#include <QLayout>
+#include <QCheckBox>
+#include <QSplitter>
+#include <QDir>
+#include <QFile>
+#include <QLineEdit>
+#include <QComboBox>
 #include <QDropEvent>
 #include <QUrl>
 #include <QProcess>
@@ -427,11 +427,11 @@ void KDiff3App::init( bool bAuto, TotalDiffStatus* pTotalDiffStatus, bool bLoadF
    if ( bGUI )
    {
       const ManualDiffHelpList* pMDHL = &m_manualDiffHelpList;
-      m_pDiffTextWindow1->init( m_sd1.getAliasName(),
+      m_pDiffTextWindow1->init( m_sd1.getAliasName(), m_sd1.getEncoding(), m_sd1.getLineEndStyle(),
          m_sd1.getLineDataForDisplay(), m_sd1.getSizeLines(), &m_diff3LineVector, pMDHL, m_bTripleDiff );
-      m_pDiffTextWindow2->init( m_sd2.getAliasName(),
+      m_pDiffTextWindow2->init( m_sd2.getAliasName(), m_sd2.getEncoding(), m_sd2.getLineEndStyle(),
          m_sd2.getLineDataForDisplay(), m_sd2.getSizeLines(), &m_diff3LineVector, pMDHL, m_bTripleDiff );
-      m_pDiffTextWindow3->init( m_sd3.getAliasName(),
+      m_pDiffTextWindow3->init( m_sd3.getAliasName(), m_sd3.getEncoding(), m_sd3.getLineEndStyle(),
          m_sd3.getLineDataForDisplay(), m_sd3.getSizeLines(), &m_diff3LineVector, pMDHL, m_bTripleDiff );
 
       m_pDiffTextWindowFrame3->setVisible(m_bTripleDiff);
@@ -605,7 +605,7 @@ void KDiff3App::setHScrollBarRange()
    m_pHScrollBar->setPageStep( pageStep );
 }
 
-void KDiff3App::resizeDiffTextWindow(int newWidth, int newHeight)
+void KDiff3App::resizeDiffTextWindow(int /*newWidth*/, int newHeight)
 {
    m_DTWHeight = newHeight;
 
@@ -863,7 +863,7 @@ static int calcManualDiffFirstDiff3LineIdx( const Diff3LineVector& d3lv, const M
 void KDiff3App::slotAfterFirstPaint()
 {
    int newHeight = m_pDiffTextWindow1->getNofVisibleLines();
-   int newWidth  = m_pDiffTextWindow1->getNofVisibleColumns();
+   /*int newWidth  = m_pDiffTextWindow1->getNofVisibleColumns();*/
    m_DTWHeight = newHeight;
 
    recalcWordWrap();
@@ -1763,11 +1763,11 @@ bool KDiff3App::improveFilenames( bool bCreateNewInstance )
          if (bSuccess)
          {
             m_sd1.reset();
-            if (m_pDiffTextWindow1!=0) m_pDiffTextWindow1->init(0,0,0,0,0,false);
+            if (m_pDiffTextWindow1!=0) m_pDiffTextWindow1->init(0,0,eLineEndStyleDos,0,0,0,0,false);
             m_sd2.reset();
-            if (m_pDiffTextWindow2!=0) m_pDiffTextWindow2->init(0,0,0,0,0,false);
+            if (m_pDiffTextWindow2!=0) m_pDiffTextWindow2->init(0,0,eLineEndStyleDos,0,0,0,0,false);
             m_sd3.reset();
-            if (m_pDiffTextWindow3!=0) m_pDiffTextWindow3->init(0,0,0,0,0,false);
+            if (m_pDiffTextWindow3!=0) m_pDiffTextWindow3->init(0,0,eLineEndStyleDos,0,0,0,0,false);
          }
          slotUpdateAvailabilities();
          return bSuccess;
